@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2013 Emweb bvba, Leuven, Belgium.
+ * Copyright (C) 2013 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -32,7 +32,7 @@ public:
   virtual WString categoryLabel(int u, Axis axis) const override;
   
   virtual RenderRange computeRenderRange(
-      Axis axis, int yAxis, AxisScale scale = AxisScale::Linear)
+      Axis axis, int xAxis, int yAxis, AxisScale scale = AxisScale::Linear)
     const override;
 
   virtual bool onDemandLoadingEnabled() const override;
