@@ -285,8 +285,7 @@ public:
    * contain the host part!) to a favicon, which is the icon displayed
    * in the browser for your application. Alternatively, you may
    * specify a favicon using the "favicon" property in the
-   * configuration file (see als \ref config_general "EntryPointType::Application
-   * settings (wt_config.xml)").
+   * configuration file (see also \ref config_general).
    *
    * \sa removeEntryPoint()
    */
@@ -468,7 +467,15 @@ public:
    */
   WT_API void postAll(const std::function<void ()>& function);
 
-  WT_API void schedule(std::chrono::steady_clock::duration millis,
+  /*! \brief Schedules a function to be executed in a session.
+   *
+   * The \p function will run in the session specified by \p sessionId,
+   * after \p duration. If the session does not exist anymore,
+   * \p fallBackFunction will be executed.
+   *
+   * \sa post()
+   */
+  WT_API void schedule(std::chrono::steady_clock::duration duration,
 		       const std::string& sessionId,
 		       const std::function<void ()>& function,
 		       const std::function<void ()>& fallBackFunction
@@ -552,6 +559,15 @@ public:
    */
   WT_API WLogger& logger();
 
+  /*! \brief Sets a custom logger to redirect all logging to.
+   *
+   * Instead of using the server's default logger, this will send
+   * all logging to some custom WLogSink.
+   */
+  WT_API void setCustomLogger(const WLogSink &customLogger);
+
+  const WLogSink * customLogger() const;
+
   /*! \brief Adds an entry to the log.
    *
    * \sa Wt::log(), WApplication::log()
@@ -591,6 +607,7 @@ private:
 
 #ifndef WT_TARGET_JAVA
   WLogger logger_;
+  const WLogSink * customLogger_;
 #endif // WT_TARGET_JAVA
 
   std::string application_, configurationFile_, appRoot_, description_;
