@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -15,10 +15,15 @@
 #include <Wt/WJavaScript.h>
 
 #include <bitset>
+#include <cassert>
 #include <list>
 #include <vector>
 #include <sstream>
 
+#ifndef WT_TARGET_JAVA
+#include <type_traits>
+#endif // WT_TARGET_JAVA
+
 namespace Wt {
 
 enum class RepaintFlag {
@@ -82,6 +87,30 @@ public:
    */
   virtual std::unique_ptr<WWidget> removeWidget(WWidget *widget);
 
+#ifndef WT_TARGET_JAVA
+  /*! \brief Removes a child widget.
+   *
+   * This is an overload that automatically casts the returned value to a unique_ptr<Widget> for convenience
+   *
+   * This is implemented as:
+   * \code
+   * return std::unique_ptr<Widget>(static_cast<Widget*>(removeWidget(static_cast<WWidget*>(widget)).release()));
+   * \endcode
+   */
+  template<typename Widget>
+#ifdef DOXYGEN_ONLY
+  std::unique_ptr<Widget> removeWidget(Widget *widget)
+#else // DOXYGEN_ONLY
+  typename std::enable_if<std::is_convertible<Widget*,WWidget*>::value && !std::is_same<Widget,WWidget>::value, std::unique_ptr<Widget>>::type removeWidget(Widget *widget)
+#endif // DOXYGEN_ONLY
+  {
+    std::unique_ptr<WWidget> result = removeWidget(static_cast<WWidget*>(widget));
+    // The result is null or the given widget, guaranteeing that result.release() can be casted to Widget*
+    assert(result == nullptr || result.get() == widget);
+    return std::unique_ptr<Widget>(static_cast<Widget*>(result.release()));
+  }
+#endif // WT_TARGET_JAVA
+
   /*! \brief Removes the widget from its parent.
    *
    * This is equivalent to parent()->removeWidget(this);
@@ -122,7 +151,7 @@ public:
    * scheme. The widget may be shifted to the left or right by
    * specifying an offset for the \link Wt::Side::Left left\endlink or \link
    * Wt::Side::Right right\endlink) side. The widget may be shifted
-   * vertically, by specifying an offset for the \link Wt::AlignmentFlag::Top
+   * vertically, by specifying an offset for the \link Wt::Side::Top
    * top\endlink or \link Wt::Side::Bottom bottom\endlink side.
    *
    * For an \link Wt::PositionScheme::Absolute absolutely positioned\endlink widget,
@@ -363,8 +392,7 @@ public:
    *
    * This lets the widget float to one of the sides of the parent
    * widget, at the current line. A typical use is to position images
-   * within text. Valid values for Side or \if cpp Wt::None \elseif
-   * java {javadoclink Side#None None} \endif, Wt::Side::Left or Wt::Side::Right.
+   * within text. Valid values for Side Side::Left, or Side::Right.
    *
    * This applies to CSS-based layout.
    */
@@ -454,9 +482,11 @@ public:
    * visible if it and all its ancestors in the widget tree are
    * visible, which may be checked using isVisible().
    *
+   * \if cpp
    * \note hide() and show() are considered to be stateless slots by default.
    * If you override setHidden() and need to modify server state whenever it is called,
    * you'll need to call WObject::isNotStateless().
+   * \endif
    */
   virtual void setHidden(bool hidden,
 			 const WAnimation& animation = WAnimation()) = 0;
@@ -496,9 +526,11 @@ public:
    * Typically, a disabled form widget will not allow changing the
    * value, and disabled widgets will not react to mouse click events.
    *
+   * \if cpp
    * \note enable() and disable() are considered to be stateless slots by default.
    * If you override setDisabled() and need to modify server state whenever it is called,
    * you'll need to call WObject::isNotStateless().
+   * \endif
    *
    * \sa disable(), enable()
    */
@@ -719,7 +751,7 @@ public:
    *
    * The widget must actualize its contents in response.
    *
-   * \note This does *not* rerender the widget! Calling refresh() usually
+   * \note This does **not** rerender the widget! Calling refresh() usually
    *       does not have any effect (unless you've reimplemented refresh()
    *       to attach to it an effect).
    */
@@ -915,6 +947,13 @@ public:
    * letters, digits ([0-9]), hyphens ("-"), underscores ("_"), colons (":"),
    * and periods (".").
    *
+   * \warning We recommend that you leave the id of a widget unchanged. %Wt
+   * uses the id to identify widgets in the JavaScript it generates,
+   * and this can often leads to bugs. If you do change the id, **only** change
+   * the id right after widget construction. However, usually
+   * there's a more preferable alternative, like setting the object name
+   * (WObject::setObjectName), or adding style classes (WWidget::addStyleClass).
+   *
    * \sa WObject::id()
    */
   virtual void setId(const std::string& id) = 0;
@@ -1324,7 +1363,8 @@ private:
   static const int BIT_HAS_PARENT = 4;
   static const int BIT_RESIZE_AWARE = 5;
   static const int BIT_SCROLL_VISIBILITY_ENABLED = 6;
-  std::bitset<7> flags_;
+  static const int BIT_GLOBAL_WIDGET = 7;
+  std::bitset<8> flags_;
 
   EventSignalList eventSignals_;
   std::vector<EventSignalBase*> jsignals_;
@@ -1335,6 +1375,9 @@ private:
   void undoDisableEnable();
   virtual void setParentWidget(WWidget *parent);
 
+  bool isGlobalWidget() const;
+  void setGlobalWidget(bool globalWidget);
+
   virtual WWebWidget *webWidget() = 0;
 
   friend class WebRenderer;
@@ -1346,6 +1389,7 @@ private:
   friend class WCompositeWidget;
   friend class WFileUpload;
   friend class WGLWidget;
+  friend class WLeafletMap;
   friend class WMenuItem;
   friend class WPaintedWidget;
   friend class WPopupWidget;
