@@ -25,29 +25,32 @@ namespace {
 }
 
 SAMPLE_BEGIN(PlainTable)
-auto table = Wt::cpp14::make_unique<Wt::WTable>();
+auto table = std::make_unique<Wt::WTable>();
 table->setHeaderCount(1);
 table->setWidth(Wt::WLength("100%"));
 
-table->elementAt(0, 0)->addWidget(Wt::cpp14::make_unique<Wt::WText>("#"));
-table->elementAt(0, 1)->addWidget(Wt::cpp14::make_unique<Wt::WText>("First Name"));
-table->elementAt(0, 2)->addWidget(Wt::cpp14::make_unique<Wt::WText>("Last Name"));
-table->elementAt(0, 3)->addWidget(Wt::cpp14::make_unique<Wt::WText>("Pay"));
+table->elementAt(0, 0)->addNew<Wt::WText>("#");
+table->elementAt(0, 1)->addNew<Wt::WText>("First Name");
+table->elementAt(0, 2)->addNew<Wt::WText>("Last Name");
+table->elementAt(0, 3)->addNew<Wt::WText>("Pay");
 
 for (unsigned i = 0; i < 3; ++i) {
     Employee& employee = employees[i];
     int row = i + 1;
 
     table->elementAt(row, 0)
-        ->addWidget(Wt::cpp14::make_unique<Wt::WText>(Wt::WString("{1}")
-				  .arg(row)));
+        ->addNew<Wt::WText>(Wt::WString("{1}").arg(row));
     table->elementAt(row, 1)
-        ->addWidget(Wt::cpp14::make_unique<Wt::WText>(employee.firstName));
+        ->addNew<Wt::WText>(employee.firstName);
     table->elementAt(row, 2)
-        ->addWidget(Wt::cpp14::make_unique<Wt::WText>(employee.lastName));
+        ->addNew<Wt::WText>(employee.lastName);
+#ifndef WT_TARGET_JAVA
     table->elementAt(row, 3)
-        ->addWidget(Wt::cpp14::make_unique<Wt::WLineEdit>(Wt::WString("{1}")
-				      .arg(employee.pay)));
+        ->addNew<Wt::WLineEdit>(Wt::WString("{1}").arg(employee.pay));
+#else // WT_TARGET_JAVA
+    table->elementAt(row, 3)
+        ->addNew<Wt::WLineEdit>(Wt::WString("{1}").arg(employee.pay).toUTF8());
+#endif // WT_TARGET_JAVA
 }
 
 SAMPLE_END(return std::move(table))
