@@ -3,20 +3,20 @@
 
 SAMPLE_BEGIN(PushButtonSize)
 auto result =
-    Wt::cpp14::make_unique<Wt::WTemplate>(Wt::WString::tr("pushButtonSize-template"));
+    std::make_unique<Wt::WTemplate>(Wt::WString::tr("pushButtonSize-template"));
 
-auto button = Wt::cpp14::make_unique<Wt::WPushButton>("Large");
+auto button = std::make_unique<Wt::WPushButton>("Large");
 button->setStyleClass("btn-lg");
 result->bindWidget("button-large", std::move(button));
 
-button = Wt::cpp14::make_unique<Wt::WPushButton>("Default");
+button = std::make_unique<Wt::WPushButton>("Default");
 result->bindWidget("button-default", std::move(button));
 
-button = Wt::cpp14::make_unique<Wt::WPushButton>("Small");
+button = std::make_unique<Wt::WPushButton>("Small");
 button->setStyleClass("btn-sm");
 result->bindWidget("button-small", std::move(button));
 
-button = Wt::cpp14::make_unique<Wt::WPushButton>("Mini");
+button = std::make_unique<Wt::WPushButton>("Mini");
 button->setStyleClass("btn-xs");
 result->bindWidget("button-mini", std::move(button));
 
